{
    "$graph": [
        {
            "class": "CommandLineTool",
            "arguments": [
                "$(inputs.java)",
                "-Xmx50g",
                "-Djava.io.tmpdir=$(runtime.tmpdir)",
                "-jar",
                "$(inputs.abra)",
                {
                    "prefix": "--tmpdir",
                    "valueFrom": "$(runtime.tmpdir)"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": "$(inputs.ram_min)",
                    "coresMin": "$(inputs.cores_min)",
                    "outdirMax": 120000,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#abra.cwl/abra"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--ca"
                    },
                    "id": "#abra.cwl/ca"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "--cons"
                    },
                    "id": "#abra.cwl/cons"
                },
                {
                    "type": "int",
                    "id": "#abra.cwl/cores_min"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "--index"
                    },
                    "id": "#abra.cwl/index"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "prefix": "--in",
                        "itemSeparator": ","
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#abra.cwl/input_bams"
                },
                {
                    "type": "string",
                    "id": "#abra.cwl/java"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--kmer"
                    },
                    "id": "#abra.cwl/kmer"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--mad"
                    },
                    "id": "#abra.cwl/mad"
                },
                {
                    "type": "float",
                    "inputBinding": {
                        "prefix": "--mmr"
                    },
                    "id": "#abra.cwl/mmr"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "inputBinding": {
                        "itemSeparator": ",",
                        "prefix": "--out"
                    },
                    "id": "#abra.cwl/out"
                },
                {
                    "type": "string",
                    "id": "#abra.cwl/patient_id"
                },
                {
                    "type": "int",
                    "id": "#abra.cwl/ram_min"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--ref"
                    },
                    "id": "#abra.cwl/reference_fasta"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--sc"
                    },
                    "id": "#abra.cwl/sc"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--sga"
                    },
                    "id": "#abra.cwl/sga"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--targets"
                    },
                    "id": "#abra.cwl/targets"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--threads"
                    },
                    "id": "#abra.cwl/threads"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--ws"
                    },
                    "id": "#abra.cwl/ws"
                }
            ],
            "id": "#abra.cwl",
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*_IR.bam",
                        "outputEval": "${\n  var sorted_output_bams = [];\n\n  inputs.out.forEach(function(output_bam_filename) {\n    self.forEach(function(realigned_bam) {\n      if (output_bam_filename === realigned_bam.basename) {\n\n        sorted_output_bams.push(realigned_bam);\n\n      }\n    });\n  });\n\n  return sorted_output_bams\n}\n"
                    },
                    "id": "#abra.cwl/bams"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "arguments": [
                "$(inputs.java)",
                "-Xmx20g",
                "-jar",
                "$(inputs.gatk)",
                "-T",
                "FindCoveredIntervals"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 25000,
                    "coresMin": 2,
                    "outdirMax": 110000,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "--input_file",
                            "position": 100
                        }
                    },
                    "id": "#FindCoveredIntervals.cwl/bams"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--coverage_threshold",
                        "position": 100
                    },
                    "id": "#FindCoveredIntervals.cwl/coverage_threshold"
                },
                {
                    "type": "string",
                    "id": "#FindCoveredIntervals.cwl/gatk"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "inputBinding": {
                        "prefix": "--allow_potentially_misencoded_quality_scores",
                        "position": 100
                    },
                    "id": "#FindCoveredIntervals.cwl/ignore_misencoded_base_qualities"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "prefix": "--intervals",
                                "position": 100
                            }
                        }
                    ],
                    "id": "#FindCoveredIntervals.cwl/intervals"
                },
                {
                    "type": "string",
                    "id": "#FindCoveredIntervals.cwl/java"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--minBaseQuality",
                        "position": 100
                    },
                    "id": "#FindCoveredIntervals.cwl/min_base_quality"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--minMappingQuality",
                        "position": 100
                    },
                    "id": "#FindCoveredIntervals.cwl/min_mapping_quality"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--out",
                        "position": 100
                    },
                    "id": "#FindCoveredIntervals.cwl/out"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "--read_filter",
                            "position": 100
                        }
                    },
                    "id": "#FindCoveredIntervals.cwl/read_filters"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--reference_sequence"
                    },
                    "id": "#FindCoveredIntervals.cwl/reference_sequence"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.out)"
                    },
                    "id": "#FindCoveredIntervals.cwl/fci_list"
                }
            ],
            "id": "#FindCoveredIntervals.cwl"
        },
        {
            "class": "CommandLineTool",
            "arguments": [
                "$(inputs.java)",
                "-Xmx24g",
                "-jar",
                "$(inputs.fix_mate_information)",
                "TMP_DIR=/scratch"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 30000,
                    "coresMin": 5,
                    "outdirMax": 20000,
                    "class": "ResourceRequirement"
                }
            ],
            "doc": "None\n",
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "COMPRESSION_LEVEL=",
                        "separate": false
                    },
                    "id": "#FixMateInformation.cwl/compression_level"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "CREATE_INDEX=true"
                    },
                    "id": "#FixMateInformation.cwl/create_index"
                },
                {
                    "type": "string",
                    "id": "#FixMateInformation.cwl/fix_mate_information"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "I=",
                        "separate": false
                    },
                    "id": "#FixMateInformation.cwl/input_bam"
                },
                {
                    "type": "string",
                    "id": "#FixMateInformation.cwl/java"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "$(inputs.input_bam.basename.replace('.bam', '_FX.bam'))",
                    "inputBinding": {
                        "prefix": "O=",
                        "separate": false,
                        "valueFrom": "$(inputs.input_bam.basename.replace('.bam', '_FX.bam'))"
                    },
                    "id": "#FixMateInformation.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "SO=",
                        "separate": false
                    },
                    "id": "#FixMateInformation.cwl/sort_order"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "TMP_DIR=",
                        "separate": false
                    },
                    "id": "#FixMateInformation.cwl/tmp_dir"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "VALIDATION_STRINGENCY=",
                        "separate": false
                    },
                    "id": "#FixMateInformation.cwl/validation_stringency"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.basename.replace('.bam', '_FX.bai'))"
                    },
                    "id": "#FixMateInformation.cwl/bai"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.basename.replace('.bam', '_FX.bam'))"
                    },
                    "id": "#FixMateInformation.cwl/bam"
                }
            ],
            "id": "#FixMateInformation.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "list2bed"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 5000,
                    "coresMin": 1,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--input_file"
                    },
                    "id": "#list2bed.cwl/input_file"
                },
                {
                    "type": "string",
                    "doc": "Name for the output bed file",
                    "inputBinding": {
                        "prefix": "--output_file"
                    },
                    "id": "#list2bed.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "doc": "Whether to sort bed file output",
                    "inputBinding": {
                        "prefix": "--sort"
                    },
                    "id": "#list2bed.cwl/sort"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${return inputs.output_filename}"
                    },
                    "id": "#list2bed.cwl/output_file"
                }
            ],
            "id": "#list2bed.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "types": [
                        {
                            "type": "record",
                            "name": "#collapsing_tools.yaml/run_tools",
                            "fields": [
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/perl_5",
                                    "type": "string"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/java_7",
                                    "type": "string"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/java_8",
                                    "type": "string"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/marianas_path",
                                    "type": "string"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/bioinfo_utils",
                                    "type": "File"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/trimgalore_path",
                                    "type": "string"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/bwa_path",
                                    "type": "string"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/arrg_path",
                                    "type": "string"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/picard_path",
                                    "type": "string"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/gatk_path",
                                    "type": "string"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/abra_path",
                                    "type": "string"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/fx_path",
                                    "type": "string"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/waltz_path",
                                    "type": "string"
                                }
                            ]
                        },
                        {
                            "name": "#find_covered_intervals.yaml/find_covered_intervals__params",
                            "type": "record",
                            "fields": [
                                {
                                    "name": "#find_covered_intervals.yaml/find_covered_intervals__params/minbq",
                                    "type": "int"
                                },
                                {
                                    "name": "#find_covered_intervals.yaml/find_covered_intervals__params/minmq",
                                    "type": "int"
                                },
                                {
                                    "name": "#find_covered_intervals.yaml/find_covered_intervals__params/cov",
                                    "type": "int"
                                },
                                {
                                    "name": "#find_covered_intervals.yaml/find_covered_intervals__params/rf",
                                    "type": {
                                        "type": "array",
                                        "items": "string"
                                    }
                                },
                                {
                                    "name": "#find_covered_intervals.yaml/find_covered_intervals__params/intervals",
                                    "type": [
                                        "null",
                                        {
                                            "type": "array",
                                            "items": "string"
                                        }
                                    ]
                                }
                            ]
                        },
                        {
                            "name": "#abra.yaml/abra__params",
                            "type": "record",
                            "fields": [
                                {
                                    "name": "#abra.yaml/abra__params/ram_min",
                                    "type": "int"
                                },
                                {
                                    "name": "#abra.yaml/abra__params/cores_min",
                                    "type": "int"
                                },
                                {
                                    "name": "#abra.yaml/abra__params/threads",
                                    "type": "int"
                                },
                                {
                                    "name": "#abra.yaml/abra__params/kmers",
                                    "type": [
                                        "null",
                                        "string"
                                    ]
                                },
                                {
                                    "name": "#abra.yaml/abra__params/mad",
                                    "type": "int"
                                },
                                {
                                    "name": "#abra.yaml/abra__params/sc",
                                    "type": "string"
                                },
                                {
                                    "name": "#abra.yaml/abra__params/mmr",
                                    "type": "float"
                                },
                                {
                                    "name": "#abra.yaml/abra__params/sga",
                                    "type": "string"
                                },
                                {
                                    "name": "#abra.yaml/abra__params/ca",
                                    "type": "string"
                                },
                                {
                                    "name": "#abra.yaml/abra__params/ws",
                                    "type": "string"
                                },
                                {
                                    "name": "#abra.yaml/abra__params/index",
                                    "type": "boolean"
                                },
                                {
                                    "name": "#abra.yaml/abra__params/cons",
                                    "type": "boolean"
                                }
                            ]
                        },
                        {
                            "name": "#fix_mate_information.yaml/fix_mate_information__params",
                            "type": "record",
                            "fields": [
                                {
                                    "name": "#fix_mate_information.yaml/fix_mate_information__params/sort_order",
                                    "type": "string"
                                },
                                {
                                    "name": "#fix_mate_information.yaml/fix_mate_information__params/validation_stringency",
                                    "type": "string"
                                },
                                {
                                    "name": "#fix_mate_information.yaml/fix_mate_information__params/compression_level",
                                    "type": "int"
                                },
                                {
                                    "name": "#fix_mate_information.yaml/fix_mate_information__params/create_index",
                                    "type": "boolean"
                                }
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "#abra.yaml/abra__params",
                    "id": "#main/abra__params"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#main/bams"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/fci__basq_fix"
                },
                {
                    "type": "#find_covered_intervals.yaml/find_covered_intervals__params",
                    "id": "#main/find_covered_intervals__params"
                },
                {
                    "type": "#fix_mate_information.yaml/fix_mate_information__params",
                    "id": "#main/fix_mate_information__params"
                },
                {
                    "type": "string",
                    "id": "#main/patient_id"
                },
                {
                    "type": "string",
                    "id": "#main/reference_fasta"
                },
                {
                    "type": "#collapsing_tools.yaml/run_tools",
                    "id": "#main/run_tools"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/list2bed/output_file",
                    "id": "#main/covint_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#main/find_covered_intervals/fci_list",
                    "id": "#main/covint_list"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "outputSource": "#main/parallel_fixmate/bams",
                    "id": "#main/ir_bams"
                }
            ],
            "steps": [
                {
                    "run": "#abra.cwl",
                    "in": [
                        {
                            "valueFrom": "$(inputs.run_tools.abra_path)",
                            "id": "#main/abra/abra"
                        },
                        {
                            "valueFrom": "$(inputs.params.ca)",
                            "id": "#main/abra/ca"
                        },
                        {
                            "valueFrom": "$(inputs.params.cons)",
                            "id": "#main/abra/cons"
                        },
                        {
                            "valueFrom": "$(inputs.params.cores_min)",
                            "id": "#main/abra/cores_min"
                        },
                        {
                            "valueFrom": "$(inputs.params.index)",
                            "id": "#main/abra/index"
                        },
                        {
                            "source": "#main/bams",
                            "id": "#main/abra/input_bams"
                        },
                        {
                            "valueFrom": "$(inputs.run_tools.java_8)",
                            "id": "#main/abra/java"
                        },
                        {
                            "valueFrom": "$(inputs.params.mad)",
                            "id": "#main/abra/mad"
                        },
                        {
                            "valueFrom": "$(inputs.params.mmr)",
                            "id": "#main/abra/mmr"
                        },
                        {
                            "valueFrom": "$(inputs.input_bams.map(function(b){return b.basename.replace('.bam', '_IR.bam')}))",
                            "id": "#main/abra/out"
                        },
                        {
                            "source": "#main/abra__params",
                            "id": "#main/abra/params"
                        },
                        {
                            "source": "#main/patient_id",
                            "id": "#main/abra/patient_id"
                        },
                        {
                            "valueFrom": "$(inputs.params.ram_min)",
                            "id": "#main/abra/ram_min"
                        },
                        {
                            "source": "#main/reference_fasta",
                            "id": "#main/abra/reference_fasta"
                        },
                        {
                            "source": "#main/run_tools",
                            "id": "#main/abra/run_tools"
                        },
                        {
                            "valueFrom": "$(inputs.params.sc)",
                            "id": "#main/abra/sc"
                        },
                        {
                            "valueFrom": "$(inputs.params.sga)",
                            "id": "#main/abra/sga"
                        },
                        {
                            "source": "#main/list2bed/output_file",
                            "id": "#main/abra/targets"
                        },
                        {
                            "valueFrom": "$(inputs.params.threads)",
                            "id": "#main/abra/threads"
                        },
                        {
                            "valueFrom": "$(inputs.params.ws)",
                            "id": "#main/abra/ws"
                        }
                    ],
                    "out": [
                        "#main/abra/bams"
                    ],
                    "id": "#main/abra"
                },
                {
                    "run": "#FindCoveredIntervals.cwl",
                    "in": [
                        {
                            "source": "#main/bams",
                            "id": "#main/find_covered_intervals/bams"
                        },
                        {
                            "valueFrom": "$(inputs.params.cov)",
                            "id": "#main/find_covered_intervals/coverage_threshold"
                        },
                        {
                            "valueFrom": "$(inputs.run_tools.gatk_path)",
                            "id": "#main/find_covered_intervals/gatk"
                        },
                        {
                            "source": "#main/fci__basq_fix",
                            "id": "#main/find_covered_intervals/ignore_misencoded_base_qualities"
                        },
                        {
                            "valueFrom": "${\n  return inputs.params.intervals ? inputs.params.intervals : null\n}\n",
                            "id": "#main/find_covered_intervals/intervals"
                        },
                        {
                            "valueFrom": "$(inputs.run_tools.java_7)",
                            "id": "#main/find_covered_intervals/java"
                        },
                        {
                            "valueFrom": "$(inputs.params.minbq)",
                            "id": "#main/find_covered_intervals/min_base_quality"
                        },
                        {
                            "valueFrom": "$(inputs.params.minmq)",
                            "id": "#main/find_covered_intervals/min_mapping_quality"
                        },
                        {
                            "valueFrom": "${return inputs.patient_id + '.fci.list'}",
                            "id": "#main/find_covered_intervals/out"
                        },
                        {
                            "source": "#main/find_covered_intervals__params",
                            "id": "#main/find_covered_intervals/params"
                        },
                        {
                            "source": "#main/patient_id",
                            "id": "#main/find_covered_intervals/patient_id"
                        },
                        {
                            "valueFrom": "$(inputs.params.rf)",
                            "id": "#main/find_covered_intervals/read_filters"
                        },
                        {
                            "source": "#main/reference_fasta",
                            "id": "#main/find_covered_intervals/reference_sequence"
                        },
                        {
                            "source": "#main/run_tools",
                            "id": "#main/find_covered_intervals/run_tools"
                        }
                    ],
                    "out": [
                        "#main/find_covered_intervals/fci_list"
                    ],
                    "id": "#main/find_covered_intervals"
                },
                {
                    "run": "#list2bed.cwl",
                    "in": [
                        {
                            "source": "#main/find_covered_intervals/fci_list",
                            "id": "#main/list2bed/input_file"
                        },
                        {
                            "valueFrom": "${return inputs.input_file.basename.replace('.list', '.bed.srt')}",
                            "id": "#main/list2bed/output_filename"
                        }
                    ],
                    "out": [
                        "#main/list2bed/output_file"
                    ],
                    "id": "#main/list2bed"
                },
                {
                    "in": [
                        {
                            "source": "#main/abra/bams",
                            "id": "#main/parallel_fixmate/bam"
                        },
                        {
                            "valueFrom": "$(inputs.params.compression_level)",
                            "id": "#main/parallel_fixmate/compression_level"
                        },
                        {
                            "valueFrom": "$(inputs.params.create_index)",
                            "id": "#main/parallel_fixmate/create_index"
                        },
                        {
                            "valueFrom": "$(inputs.run_tools.fx_path)",
                            "id": "#main/parallel_fixmate/fix_mate_information"
                        },
                        {
                            "valueFrom": "$(inputs.run_tools.java_7)",
                            "id": "#main/parallel_fixmate/java"
                        },
                        {
                            "source": "#main/fix_mate_information__params",
                            "id": "#main/parallel_fixmate/params"
                        },
                        {
                            "source": "#main/run_tools",
                            "id": "#main/parallel_fixmate/run_tools"
                        },
                        {
                            "valueFrom": "$(inputs.params.sort_order)",
                            "id": "#main/parallel_fixmate/sort_order"
                        },
                        {
                            "valueFrom": "$(inputs.params.validation_stringency)",
                            "id": "#main/parallel_fixmate/validation_stringency"
                        }
                    ],
                    "out": [
                        "#main/parallel_fixmate/bams"
                    ],
                    "scatter": [
                        "#main/parallel_fixmate/bam"
                    ],
                    "scatterMethod": "dotproduct",
                    "run": {
                        "class": "Workflow",
                        "inputs": [
                            {
                                "type": "File",
                                "id": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/bam"
                            },
                            {
                                "type": "int",
                                "id": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/compression_level"
                            },
                            {
                                "type": "boolean",
                                "id": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/create_index"
                            },
                            {
                                "type": "string",
                                "id": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/fix_mate_information"
                            },
                            {
                                "type": "string",
                                "id": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/java"
                            },
                            {
                                "type": "string",
                                "id": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/sort_order"
                            },
                            {
                                "type": "string",
                                "id": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/validation_stringency"
                            }
                        ],
                        "outputs": [
                            {
                                "type": "File",
                                "outputSource": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/picard_fixmate_information/bam",
                                "id": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/bams"
                            }
                        ],
                        "steps": [
                            {
                                "run": "#FixMateInformation.cwl",
                                "in": [
                                    {
                                        "source": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/compression_level",
                                        "id": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/picard_fixmate_information/compression_level"
                                    },
                                    {
                                        "source": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/create_index",
                                        "id": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/picard_fixmate_information/create_index"
                                    },
                                    {
                                        "source": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/fix_mate_information",
                                        "id": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/picard_fixmate_information/fix_mate_information"
                                    },
                                    {
                                        "source": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/bam",
                                        "id": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/picard_fixmate_information/input_bam"
                                    },
                                    {
                                        "source": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/java",
                                        "id": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/picard_fixmate_information/java"
                                    },
                                    {
                                        "source": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/sort_order",
                                        "id": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/picard_fixmate_information/sort_order"
                                    },
                                    {
                                        "source": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/validation_stringency",
                                        "id": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/picard_fixmate_information/validation_stringency"
                                    }
                                ],
                                "out": [
                                    "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/picard_fixmate_information/bam"
                                ],
                                "id": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8/picard_fixmate_information"
                            }
                        ],
                        "id": "#main/parallel_fixmate/44bc661e-2e0d-418e-b36d-e8f04cd3f2a8"
                    },
                    "id": "#main/parallel_fixmate"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
